Temporal examples
=================

.. toctree::
   :maxdepth: 1

   01-era5-general-methods.ipynb
   02-era5-daily-monthly-statistics.ipynb
   03-seas5-daily-statistics.ipynb
   04-era5-bespoke-how-function.ipynb
